[GHC] #7460: Double literals generated bad core
GHC
cvs-ghc at haskell.org
Wed Dec 5 19:33:53 CET 2012
#7460: Double literals generated bad core
---------------------------------+------------------------------------------
Reporter: tibbe | Owner:
Type: bug | Status: new
Priority: normal | Milestone:
Component: Compiler | Version: 7.4.2
Keywords: | Os: Unknown/Multiple
Architecture: Unknown/Multiple | Failure: Runtime performance bug
Difficulty: Unknown | Testcase:
Blockedby: | Blocking:
Related: |
---------------------------------+------------------------------------------
Comment(by tibbe):
This came up as we investigated the performance of the above program under
7.4. int-e reports the following run-times:
{{{
int-e: so ghc-7.0.3 has calls to integer_cmm_word2Integerzh and
integer_cbits_encodeDouble instead of doubleFromInteger (wordToInteger
...), so what is the difference?
[10:15am] int-e: tibbe: I get
http://int-e.cohomology.org/~bf3/haskell/doubles-7.0.3.core and
http://int-e.cohomology.org/~bf3/haskell/doubles-7.4.1.core both with -O2
-ddump-simpl
[10:17am] tibbe: int-e: I wonder what cmm integer_cbits_encodeDouble
generates
[10:17am] tibbe: int-e: whatever it does it makes a big difference to
performance
[10:27am] int-e: hmm, how big? I have 0.28s from 7.0.3, 0.27 from 7.2.1
and 0.34s from 7.4.1. 0.3 from 7.6.1. Similar for -O1.
[10:28am] int-e: (x86_64)
[10:31am] int-e: x86 is more pronounced. 0m1.903s / 0m1.794s / 0m2.511s /
0m2.046s for 7.0.3, 7.2.1, 7.4.1, 7.6.1
[10:31am] int-e: (-O1)
[10:31am] tibbe: int-e: so 20% on x86-64
[10:31am] int-e: (and atom)
}}}
--
Ticket URL: <http://hackage.haskell.org/trac/ghc/ticket/7460#comment:8>
GHC <http://www.haskell.org/ghc/>
The Glasgow Haskell Compiler
More information about the Glasgow-haskell-bugs
mailing list